KdbxCustomItem class
A KDBX custom item.
Constructors
- KdbxCustomItem({required String value, KdbxTime? modification})
-
Constructs a new KdbxCustomItem from provided
valueandmodificationtime.
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- modification ↔ KdbxTime
-
Time of the custom item modification.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value ↔ String
-
The text value of the custom item.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override