KdbxGroup class
A KDBX group.
Constructors
- KdbxGroup.copyFrom(KdbxGroup other, KdbxUuid id)
-
Clones
otherwithid.factory - KdbxGroup.create({required String name, required KdbxIcon icon, required KdbxUuid id, KdbxGroup? parent, bool? enableAutoType, bool? enableSearching})
-
Constructs a KdbxGroup with
name,iconandid.factory - KdbxGroup.fromXml(XmlNode node, KdbxHeader header, bool binaryTime, {KdbxGroup? parent})
-
Constructs a KdbxGroup from the XML
node.factory
Properties
-
allEntries
→ List<
KdbxEntry> -
All the entries contained in this group and in children.
no setter
-
allGroups
→ List<
KdbxGroup> -
All the groups contained in this group and in children.
no setter
-
allItems
→ List<
KdbxItem> -
All the items contained in this group and in children,
including this group itself.
no setter
-
children
→ List<
KdbxItem> -
All the children items.
no setter
- customData ↔ KdbxCustomData?
-
The custom data property.
getter/setter pairinherited
- customIcon ↔ KdbxUuid?
-
The custom icon ID.
getter/setter pairinherited
- defaultAutoTypeSeq ↔ String?
-
The default autotype sequence.
getter/setter pair
-
entries
↔ List<
KdbxEntry> -
The collection of contained entries.
getter/setter pair
-
groups
↔ List<
KdbxGroup> -
The collection of contained groups.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon ↔ KdbxIcon
-
The standard icon.
getter/setter pairinherited
- isAutoTypeEnabled ↔ bool?
-
Whether autotype is enabled.
getter/setter pair
- isExpanded ↔ bool?
-
Whether group is expanded.
getter/setter pair
- isSearchingEnabled ↔ bool?
-
Whether searching is enabled in this group.
getter/setter pair
- lastTopVisibleEntry ↔ KdbxUuid?
-
Tha last top visible entry of this group.
getter/setter pair
- name ↔ String
-
The group name.
getter/setter pair
- notes ↔ String
-
The group notes.
getter/setter pair
- parent ↔ KdbxGroup?
-
The parent group.
getter/setter pairinherited
- previousParent ↔ KdbxUuid?
-
The previous parent.
getter/setter pairinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
The list of the tags.
getter/setter pairinherited
- times ↔ KdbxTimes
-
The KdbxTimes property.
getter/setter pairinherited
- uuid ↔ KdbxUuid
-
The ID of the item.
getter/setter pairinherited
Methods
-
appendToXml(
{required XmlNode node, required bool is41, required bool binaryTime}) → dynamic -
Appends the item to the XML
node.inherited -
merge(
MergeObjectMap objectMap) → dynamic -
Merges remote
objectMapto the item.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
toXml(
{required KdbxHeader header, required bool exportXml, required bool binaryTime, required bool includeHistory}) → XmlNode -
Serializes the item to an XML node.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited